@@ -25,7 +25,7 @@ REST_FRAMEWORK = {
     ),
     "DEFAULT_AUTHENTICATION_CLASSES": (
         "rest_framework.authentication.TokenAuthentication"
-        "rest_framework.authentication.SessionAuthentication"
+        "camomilla.authentication.SessionAuthentication"
     ),
 }
 
